User Reference
==============

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   ordb
   ord2
   ord1
   cell_and_generate
   schema
   geoprim
   rational
   constraints
   extlibrary
   layout

.. _data-schema:

.. figure:: architecture.svg
   :scale: 120 %
   :alt: ORDeC architecture block diagram

   Overview of ORDeC's architecture
